@@ -29,6 +29,7 @@ import pathlib
 import shutil
 import site
 import sys
+import warnings
 from pathlib import Path
 from typing import TYPE_CHECKING
 
@@ -56,7 +57,7 @@ from ansiblelint.config import (
     log_entries,
     options,
 )
-from ansiblelint.loaders import load_ignore_txt
+from ansiblelint.loaders import IgnoreRule, IgnoreRuleQualifier, load_ignore_txt
 from ansiblelint.output import (
     console,
     console_stderr,
@@ -217,7 +218,9 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
 
     # pylint: enable=import-outside-toplevel
 
-    if Version(ruamel_safe_version) > Version(ruamel_yaml_version_str):
+    if Version(ruamel_safe_version) > Version(
+        ruamel_yaml_version_str
+    ):  # pragma: no cover
         _logger.warning(
             "We detected use of `--fix` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
             ruamel_yaml_version_str,
@@ -226,7 +229,7 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
     acceptable_tags = {"all", "none", *rules.known_tags()}
     unknown_tags = set(options.write_list).difference(acceptable_tags)
 
-    if unknown_tags:
+    if unknown_tags:  # pragma: no cover
         _logger.error(
             "Found invalid value(s) (%s) for --fix arguments, must be one of: %s",
             ", ".join(unknown_tags),
@@ -269,39 +272,67 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
         result.matches.pop(idx)
 
 
-# pylint: disable=too-many-locals
+# By default, matches ignored in .ansible-lint-ignore are treated
+# as warnings [1].  If the user explicitly adds a skip qualifier
+# to the rule, it is treated as skipped here and does not show up
+# even as a warning.
+# [1] https://github.com/ansible/ansible-lint/issues/3068
+def _rule_is_skipped(tag: str, rules: set[IgnoreRule]) -> bool:
+    for rule in rules:
+        if tag != rule.rule:
+            return False
+        return IgnoreRuleQualifier.SKIP in rule.qualifiers
+    return False
+
+
+# pylint: disable=too-many-locals,too-many-statements
 def main(argv: list[str] | None = None) -> int:
     """Linter CLI entry point."""
+    must_exit = False
     # alter PATH if needed (venv support)
     path_inject(argv[0] if argv and argv[0] else "")
 
     if argv is None:  # pragma: no cover
         argv = sys.argv
-    cache_dir_lock = initialize_options(argv[1:])
 
-    reconfigure(colored=options.colored)
+    warnings.simplefilter(
+        "ignore", ResourceWarning
+    )  # suppress "enable tracemalloc to get the object allocation traceback"
+    with warnings.catch_warnings(record=True) as warns:
+        # do not use "ignore" as we will miss to collect them
+        warnings.simplefilter(action="default")
 
-    if options.version:
-        deps = get_deps_versions()
-        msg = f"ansible-lint [repr.number]{__version__}[/] using[dim]"
-        for k, v in deps.items():
-            msg += f" {k}:[repr.number]{v}[/]"
-        msg += "[/]"
-        console.print(msg)
-        msg = get_version_warning()
-        if msg:
+        cache_dir_lock = initialize_options(argv[1:])
+
+        reconfigure(colored=options.colored)
+
+        if options.version:
+            deps = get_deps_versions()
+            msg = f"ansible-lint [repr.number]{__version__}[/] using[dim]"
+            for k, v in deps.items():
+                msg += f" {k}:[repr.number]{v}[/]"
+            msg += "[/]"
             console.print(msg)
-        support_banner()
+            msg = get_version_warning()
+            if msg:  # pragma: no cover
+                console.print(msg)
+            support_banner()
+            must_exit = True
+        else:
+            support_banner()
+
+        initialize_logger(options.verbosity)
+        for level, message in log_entries:
+            _logger.log(level, message)
+        _logger.debug("Options: %s", options)
+        _logger.debug("CWD: %s", Path.cwd())
+
+    for warn in warns:  # pragma: no cover
+        _logger.warning(str(warn.message))
+    warnings.resetwarnings()
+
+    if must_exit:
         sys.exit(0)
-    else:
-        support_banner()
-
-    initialize_logger(options.verbosity)
-    for level, message in log_entries:
-        _logger.log(level, message)
-    _logger.debug("Options: %s", options)
-    _logger.debug("CWD: %s", Path.cwd())
-
     # checks if we have `ANSIBLE_LINT_SKIP_SCHEMA_UPDATE` set to bypass schema
     # update. Also skip if in offline mode.
     # env var set to skip schema refresh
@@ -318,7 +349,7 @@ def main(argv: list[str] | None = None) -> int:
         or options.nodeps
     )
 
-    if not skip_schema_update:
+    if not skip_schema_update:  # pragma: no cover
         # pylint: disable=import-outside-toplevel
         from ansiblelint.schemas.__main__ import refresh_schemas
 
@@ -358,21 +389,28 @@ def main(argv: list[str] | None = None) -> int:
 
     # Remove skip_list items from the result
     result.matches = [m for m in result.matches if m.tag not in app.options.skip_list]
-    # Mark matches as ignored inside ignore file
+    # load ignore file
     ignore_map = load_ignore_txt(options.ignore_file)
+    # prune qualified skips from ignore file
+    result.matches = [
+        m for m in result.matches if not _rule_is_skipped(m.tag, ignore_map[m.filename])
+    ]
+    # others entries are ignored
     for match in result.matches:
-        if match.tag in ignore_map[match.filename]:
+        if match.tag in [
+            i.rule for i in ignore_map[match.filename]
+        ]:  # pragma: no cover
             match.ignored = True
             _logger.debug("Ignored: %s", match)
 
-    if app.yamllint_config.incompatible:
+    if app.yamllint_config.incompatible:  # pragma: no cover
         _logger.log(
             level=logging.ERROR if options.write_list else logging.WARNING,
             msg=app.yamllint_config.incompatible,
         )
 
     if options.write_list:
-        if app.yamllint_config.incompatible:
+        if app.yamllint_config.incompatible:  # pragma: no cover
             sys.exit(RC.INVALID_CONFIG)
         fix(runtime_options=options, result=result, rules=rules)
 
@@ -438,16 +476,16 @@ def path_inject(own_location: str = "") -> None:
         str(userbase_bin_path) not in paths
         and (userbase_bin_path / "bin" / "ansible").exists()
     ):
-        inject_paths.append(str(userbase_bin_path))
+        inject_paths.append(userbase_bin_path.resolve().as_posix())
 
-    py_path = Path(sys.executable).parent
+    py_path = Path(sys.executable).parent.resolve()
     pipx_path = os.environ.get("PIPX_HOME", "pipx")
     if (
         str(py_path) not in paths
         and (py_path / "ansible").exists()
         and pipx_path not in str(py_path)
     ):
-        inject_paths.append(str(py_path))
+        inject_paths.append(py_path.as_posix())
 
     # last option, if nothing else is found, just look next to ourselves...
     if own_location:
@@ -469,7 +507,7 @@ def path_inject(own_location: str = "") -> None:
     # functioning or that is in fact the same version that was installed as
     # our dependency, but addressing this would be done by ansible-compat.
     for cmd in ("ansible",):
-        if not shutil.which(cmd):
+        if not shutil.which(cmd):  # pragma: no cover
             msg = f"Failed to find runtime dependency '{cmd}' in PATH"
             raise RuntimeError(msg)
 
